/*
LinuxCNC Plasma configuration.
*/

include("GCode.js");

function Plasma(documentInterface, newDocumentInterface) {
    GCode.call(this, documentInterface, newDocumentInterface);

    // set output unit:
    this.unit = RS.Inch;

    // use 'PlasmaLayer.ui' for layer options instead of 'GCodeLayer.ui':
    this.layerOptions = "PlasmaLayer";
}

Plasma.prototype = new GCode();

// change file extension from nc to ngc
Plasma.prototype.getFileExtensions = function() {
    // set output file extension:
    return ["ngc"];
};

// change Global Options to inch
Plasma.prototype.initGlobalOptionWidget = function(w) {
    switch (w.objectName) {
    case "ZSafety":
        w.addItems(["2", "1", "0.5"]);         // available options in combo box
        w.setEditText("0.5");                    // preselected default option
        break;
    case "ZClear":
        w.addItems(["0.25", "0.5", "1"]);
        w.setEditText("0.25");
        break;
    case "ZCutting":
        w.addItems(["-0.125", "-0.25", "-0.5"]);
        w.setEditText("-0.125");
        break;
    }
};

// set up Layer Options for Plasma
Plasma.prototype.initLayerOptionWidget = function(w) {
    switch (w.objectName) {
    case "PierceHeight":
        w.addItems(["0.125", "0.150", "0.175"]);
        w.setEditText("0.125");
        break;
    case "PierceDelay":
        w.addItems(["0.5", "1.0", "1.5"]);
        w.setEditText("0.5");
        break;
    case "CutHeight":
        w.addItems(["0.125", "0.150", "0.175"]);
        w.setEditText("0.125");
        break;
    case "TorchNozzle":
        w.addItems(["manual", "FC", "40a", "60a", "80a"]);
        w.setEditText("FC");
        break;
    case "MaterialThickness":
        w.addItems(["manual", "16ga", "14ga", "12ga", "11ga", "3/16", "1/4", "3/8"]);
        w.setEditText("11ga");
        break;
    }
};

// change G00 to G0
Plasma.prototype.getRapidMoveCode = function() {
    return "G0";
};

// change G01 to G1
Plasma.prototype.getLinearMoveCode = function() {
    return "G1";
};

// change G02 to G2
Plasma.prototype.getCircularCWMoveCode = function() {
    return "G2";
};

// change G03 to G3
Plasma.prototype.getCircularCCWMoveCode = function() {
    return "G3";
};

// add preamble
Plasma.prototype.writeHeader = function() {
    this.writeLine("G20 G17 G40 G49 G54 G64 P0.005 G80 G90 G94");
    this.writeRapidZMove(this.getSafetyZLevel());
    this.toolPosition = GCode.ToolPosition.Clear;
};

// change M30 to M2
Plasma.prototype.writeFooter = function() {
    this.writeToolUp();
    this.writeRapidZMove(this.getSafetyZLevel());
    this.toolPosition = GCode.ToolPosition.Clear;
    this.writeLine("M2");
};

// turn off line numbers
Plasma.prototype.getLineNumberCode = function() {
    return "";
};

// get the nozzle type
Plasma.prototype.getTorchNozzle = function() {
    //You can get the current layer as follows:
    var entity = this.getEntity();
    var layerId = entity.getLayerId();
    var layer = this.document.queryLayer(layerId);
    return layer.getCustomProperty("QCADCAM", "Cam/TorchNozzle", "manual");
};

// get the material thickness
Plasma.prototype.getMaterialThickness = function() {
    //You can get the current layer as follows:
    var entity = this.getEntity();
    var layerId = entity.getLayerId();
    var layer = this.document.queryLayer(layerId);
    return layer.getCustomProperty("QCADCAM", "Cam/MaterialThickness", "manual");
};


Plasma.prototype.writeToolDown = function() {
    this.g = GCode.Mode.Normal;
    this.z = this.getToolDownLevel();
    this.torchNozzle = this.getTorchNozzle();
    this.materialThickness = this.getMaterialThickness();
    switch (this.torchNozzle)
    {
    case "manual":
        qDebug("Manual");
        break;
    case "FC":
        qDebug("Fine cut");
        break;
    case "40a":
        qDebug("40 amp");
        break;
    case "60a":
        qDebug("60 amp");
        break;
    case "80a":
        qDebug("80 amp");
        break;
    default:
        qDebug("No Match");
    }
    qDebug("torch " + this.torchNozzle);
    qDebug("thickness " + this.materialThickness);
    this.toolPosition = GCode.ToolPosition.Down;
    this.writeLine();
    this.toolIsDown();
};


